Green, for clean unit test output
=================================

A plugin for the `nose2` project that provides the colored, aligned, clean
output that you deserve.  To use green, just run `green` (or `green2` or
`green3`, or `green-X.X` where `X.X` is your python version).  Alternatively,
you can run `nose2 --green`

Installation
============

For most versions of python 2.x you should use `pip`.  You may have to preface
this command with `sudo` if you do not have root permissions.

    pip install green

For more recent versions of Python 3, the command is usually nearly the same
(you still may have to preface the command with `sudo`).

    pip3 install green


Upgrading
=========

Just add the `--upgrade` option to what you used above.  For example:

    pip3 install --upgrade green


Uninstalling
============

Replace `install` with `uninstall` in the command from the Installation section
above.
